# rp2_conv

Convert CSV trade files from common Crypto exchanges to a normalized CSV / ODS file for use with [eprbell/rp2](https://github.com/eprbell/rp2/) for tax reporting.

## Purpose

A simplistic series of importers that can be used to normalize transactions from common exchanges.

### Supported Exchanges

* Coinbase & Coinbase Pro
* Kraken.com
* BitMart.com
* Binance.US
* ... add yours here!  Help us out by contributing.

## Usage

Tbd

## Contributing

We need importers for various exchanges!  Help us out by contributing.

### Roadmap

It would be nice to support public transactions from wallet addresses.

## License

MIT License, See [LICENSE](LICENSE)
